@@ -1,6 +1,6 @@
 pub use lint::Error as LintError;
 pub use lint::Lint;
-pub use lints::Error as LintsError;
+pub use lints::Error;
 pub use lints::Lints;
 pub use problem::Problem;
 
